/********************************************************************************
 * Copyright (C) 2017 Ericsson and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/

import { DisposableCollection, Emitter, Event } from '@theia/core/lib/common';
import { UserStorageChangeEvent, UserStorageService } from './user-storage-service';
import { injectable, inject } from 'inversify';
import URI from '@theia/core/lib/common/uri';
import { Range } from 'monaco-languageclient';
import { StorageService } from '@theia/core/lib/browser';

@injectable()
export class BrowserUserStorageService implements UserStorageService {

    protected readonly toDispose = new DisposableCollection();
    protected readonly onUserStorageChangedEmitter = new Emitter<UserStorageChangeEvent>();

    constructor(
        @inject(StorageService) protected readonly storageService: StorageService
    ) {
        this.toDispose.push(this.onUserStorageChangedEmitter);
    }

    dispose(): void {
        this.toDispose.dispose();
    }

    async readContents(uri: URI): Promise<{ content: string, dirty: boolean, revision: { origin: string; seq: number; }; selection?: Range }> { // codetogether
        const content = await this.storageService.getData(uri.toString(), '');
        return {
            content: content,
            dirty: false,
            revision: { origin: '', seq: 0 }
        };
    }

    async saveContents(uri: URI, content: string): Promise<void> {
        await this.storageService.setData(uri.toString(), content);
    }

    get onUserStorageChanged(): Event<UserStorageChangeEvent> {
        return this.onUserStorageChangedEmitter.event;
    }

}
